@@ -75,16 +75,16 @@ rendering is done in the index-mode.
     #define     HELPFILE        {"/yaprod/yae55/Linux_x86_64/bin/cgx_doc/cgx.html",\
                              "/yaprod/yae55/Linux_x86_64/bin/ccx_doc/ccx.html"}
   #else
-    #define     HELPFILE        {"/yaprod/cae/application/CalculiX/doc/cgx_2.10/cgx.html",\
-                             "/yaprod/cae/application/CalculiX/doc/ccx_2.10/ccx.html"}
+    #define     HELPFILE        {"/yaprod/cae/application/CalculiX/doc/cgx_2.11/cgx.html",\
+                             "/yaprod/cae/application/CalculiX/doc/ccx_2.11/ccx.html"}
   #endif
 #elif defined AFLIB
-  #define     HELPFILE        {"/usr/local/CalculiX/cgx_2.10/doc/cgx/cgx.html",\
-    "/usr/local/CalculiX/ccx_2.10/doc/ccx/ccx.html",\
-    "/usr/local/CalculiX/cgx_2.10/doc/aflib/aflib.pdf"}
+  #define     HELPFILE        {"/usr/local/CalculiX/cgx_2.11/doc/cgx/cgx.html",\
+    "/usr/local/CalculiX/ccx_2.11/doc/ccx/ccx.html",\
+    "/usr/local/CalculiX/cgx_2.11/doc/aflib/aflib.pdf"}
 #else
-  #define     HELPFILE        {"/usr/local/CalculiX/cgx_2.10/doc/cgx/cgx.html",\
-    "/usr/local/CalculiX/ccx_2.10/doc/ccx/ccx.html"}
+  #define     HELPFILE        {"/usr/local/CalculiX/cgx_2.11/doc/cgx/cgx.html",\
+    "/usr/local/CalculiX/ccx_2.11/doc/ccx/ccx.html"}
 #endif
 
 /* html browser, change if necessary */
@@ -378,8 +378,8 @@ void bak_delBody( int anz, int *number );
 void delBody( int anz, int *number );
 int  gbod_i( char *name, int blend, int anz_c, char *cori, int *corner );
 int  gbod( char *name, char *blend, int anz_c, char *cori, char *corner );
-void pre_gbod( char *record, int addFlag);
-void pre_body( char *record);
+int  pre_gbod( char *record, int addFlag);
+int  pre_body( char *record);
 int  nurl( char *string, int addFlag );
 void delNurs( int anz, int *number );
 int hashNurs( SumAsci *sumAsci, char *name, int nr);
