@@ -1608,7 +1608,7 @@ void pre_swep( char *record )
             en[n]=dep_n[k][e_enqire[e].nod[n]];
             en[n+ipuf]=dep_n[k+1][e_enqire[e].nod[n]];
           }
-          elem_define( anz->emax+1, 5-ipuf, &en[0], 1, 7 );
+          elem_define( anz->emax+1, 5-ipuf, &en[0], 1, 0 );
 
           /* add to all sets were the orig is a member */
           if(appendSetFlag) for(se=1; se<anz->sets; se++) if((se!=setNr)&&(se!=mastersetNr)&&(set[se].name!=(char *)NULL)&&(set[se].name[0]!='-'))  if(!set[se].type) if( getIndex(&set[se].elem, set[se].anz_e, e) >-1) { seta( se, "e", anz->emax );  }
@@ -1618,7 +1618,7 @@ void pre_swep( char *record )
           en[n]=e_enqire[e].nod[n];
           en[n+ipuf]=dep_n[0][e_enqire[e].nod[n]];
         }
-        elem_define( e, 5-ipuf, &en[0], 0, 7 );
+        elem_define( e, 5-ipuf, &en[0], 0, 0 );
       }
       ipuf=0;
       if (e_enqire[e].type == 8) ipuf = 6;  /* TRI6 */
@@ -1825,6 +1825,10 @@ void pre_swep( char *record )
         errMsg(" surf (%d) is undefined\n", set[setNr].surf[i] );
         goto no_swep;
       }
+
+      /* remove the now volume elements from the surface (once shells) */
+      surf[s[0]].ne=0;
+
       s[1]=dep_s[set[setNr].surf[i]];
       if (s[1]==-1)
       {
