@@ -28,7 +28,7 @@ int write2aba( char *datout, Summen *anz, Nodes *node, Elements *elem, Datasets
   FILE *handle1=NULL, *handle2=NULL;
   int  i,j, lc, n, lendatout;
   double oldtime=0, iniTime=0.001, time1=0, time2=0, frc1=0, frc2=0, tmin, tmax;
-
+  char inletflag=0;
   /* Open the files and check to see that it was opened correctly */
 
 
@@ -83,7 +83,8 @@ int write2aba( char *datout, Summen *anz, Nodes *node, Elements *elem, Datasets
       {
         if((i==0) || ((i>0)&&(elem[i-1].type!=elem[i].type)) || ((i>0)&&(elem[i-1].attr!=elem[i].attr)))
         {
-          fprintf (handle1, "*ELEMENT, TYPE=C3D4, ELSET=E%s\n", anz->model);
+          if (elem[i].attr==7) fprintf (handle1, "*ELEMENT, TYPE=F3D4, ELSET=E%s\n", anz->model);
+          else fprintf (handle1, "*ELEMENT, TYPE=C3D4, ELSET=E%s\n", anz->model);
         }
         fprintf (handle1, "%6d,%6d,%6d,%6d,%6d \n",
           elem[i].nr, elem[i].nod[0], elem[i].nod[1], elem[i].nod[2],
@@ -174,10 +175,10 @@ int write2aba( char *datout, Summen *anz, Nodes *node, Elements *elem, Datasets
       {
         if((i==0) || ((i>0)&&(elem[i-1].type!=elem[i].type)) || ((i>0)&&(elem[i-1].attr!=elem[i].attr)))
         {
-          if (elem[i].attr==4)      fprintf (handle1, "*ELEMENT, TYPE=CPE8R, ELSET=E%s\n", anz->model);
-          else if (elem[i].attr==5) fprintf (handle1, "*ELEMENT, TYPE=CPS8R, ELSET=E%s\n", anz->model);
-          else if (elem[i].attr==6) fprintf (handle1, "*ELEMENT, TYPE=CAX8R, ELSET=E%s\n", anz->model);
-          else fprintf (handle1, "*ELEMENT, TYPE=S8R, ELSET=E%s\n", anz->model);
+          if (elem[i].attr==4)      fprintf (handle1, "*ELEMENT, TYPE=CPE8, ELSET=E%s\n", anz->model);
+          else if (elem[i].attr==5) fprintf (handle1, "*ELEMENT, TYPE=CPS8, ELSET=E%s\n", anz->model);
+          else if (elem[i].attr==6) fprintf (handle1, "*ELEMENT, TYPE=CAX8, ELSET=E%s\n", anz->model);
+          else fprintf (handle1, "*ELEMENT, TYPE=S8, ELSET=E%s\n", anz->model);
         }
         fprintf (handle1, "%6d, %6d, %6d, %6d, %6d, %6d, %6d, %6d, %6d\n"
         , elem[i].nr, elem[i].nod[0], elem[i].nod[1], elem[i].nod[2], elem[i].nod[3]
@@ -185,9 +186,35 @@ int write2aba( char *datout, Summen *anz, Nodes *node, Elements *elem, Datasets
       }
       else if (elem[i].type == 11)
       {
+	printf("e:%d attr:%d\n", elem[i].nr,elem[i].attr);
         if((i==0) || ((i>0)&&(elem[i-1].type!=elem[i].type)) || ((i>0)&&(elem[i-1].attr!=elem[i].attr)))
         {
           if (elem[i].attr==3)  fprintf (handle1, "*ELEMENT, TYPE=DASHPOTA, ELSET=E%s\n", anz->model);
+          else if (elem[i].attr==7)
+	  {
+            fprintf (handle1, "*ELEMENT, TYPE=D, ELSET=E%s\n", anz->model);
+            // search the connected node
+            for (j=0; j<anz->e; j++)
+            {
+              if(elem[j].type == 12)
+	      {
+                if( (elem[j].nod[0]==elem[i].nod[0])||(elem[j].nod[2]==elem[i].nod[0]) ) { inletflag=0; break; }
+                if( (elem[j].nod[0]==elem[i].nod[1])||(elem[j].nod[2]==elem[i].nod[1]) ) { inletflag=1; break; }
+	      }
+	    }
+            if(inletflag)
+	    {
+              fprintf (handle1, "%6d, 0, %6d, %6d\n",
+                elem[i].nr, elem[i].nod[0], elem[i].nod[1] );
+              inletflag=0;
+	    }
+            else
+	    {
+              fprintf (handle1, "%6d, %6d, %6d, 0\n",
+                elem[i].nr, elem[i].nod[0], elem[i].nod[1] );
+	    }
+            continue;
+	  }
           else  fprintf (handle1, "*ELEMENT, TYPE=B31, ELSET=E%s\n", anz->model);
         }
         fprintf (handle1, "%6d, %6d, %6d\n",
@@ -197,7 +224,8 @@ int write2aba( char *datout, Summen *anz, Nodes *node, Elements *elem, Datasets
       {
         if((i==0) || ((i>0)&&(elem[i-1].type!=elem[i].type)) || ((i>0)&&(elem[i-1].attr!=elem[i].attr)))
         {
-          fprintf (handle1, "*ELEMENT, TYPE=B32R, ELSET=E%s\n", anz->model);
+          if (elem[i].attr==7) fprintf (handle1, "*ELEMENT, TYPE=D, ELSET=E%s\n", anz->model);
+	  else fprintf (handle1, "*ELEMENT, TYPE=B32R, ELSET=E%s\n", anz->model);
         }
         fprintf (handle1, "%6d, %6d, %6d, %6d\n",
           elem[i].nr, elem[i].nod[0], elem[i].nod[2], elem[i].nod[1] );
@@ -305,15 +333,15 @@ int write2aba( char *datout, Summen *anz, Nodes *node, Elements *elem, Datasets
           tmin  = time2/10.;
           tmax  = time2;
           fprintf (handle2, "** ---  LC%d ---\n", j);
-          fprintf (handle2, "*STEP, NLGEOM, INC=400, AMPLITUDE=RAMP\n");
+          fprintf (handle2, "*STEP, NLGEOM, AMPLITUDE=RAMP\n");
           fprintf (handle2, "*VISCO, CETOL=5.e-4\n");
           fprintf (handle2, "%lf, %lf,,,\n", tmin, tmax);
-          fprintf (handle2, "**CLOAD, AMPLITUDE=FORCE%d\n", j);
-          fprintf (handle2, "**include, input=ccx.clo\n");
+          fprintf (handle2, "*CLOAD, AMPLITUDE=FORCE%d\n", j);
+          fprintf (handle2, "*include, input=ccx.clo\n");
           fprintf (handle2, "*DLOAD\n");
           fprintf (handle2, "Eall, CENTRIF, %f,  0., 0., 0.,  1., 0., 0\n", frc2*(atof(dat[2])/60.*2*PI)*(atof(dat[2])/60.*2*PI));
-          fprintf (handle2, "**DLOAD, AMPLITUDE=FORCE%d\n", j);
-          fprintf (handle2, "**include, input=ccx.dlo\n");
+          fprintf (handle2, "*DLOAD, AMPLITUDE=FORCE%d\n", j);
+          fprintf (handle2, "*include, input=ccx.dlo\n");
           fprintf (handle2, "*TEMPERATURE\n");
         }
         if(compare( dat[0], "sta", 3)== 3)
@@ -324,15 +352,15 @@ int write2aba( char *datout, Summen *anz, Nodes *node, Elements *elem, Datasets
           oldtime=(lcase[lc].value);
           frc2  = (atof(lcase[lc].dataset_text)*atof(lcase[lc].dataset_text))/(atof(dat[2])*atof(dat[2]));
           fprintf (handle2, "** ---  LC%d ---\n", j);
-          fprintf (handle2, "*STEP\n");
+          fprintf (handle2, "*STEP, NLGEOM\n");
           fprintf (handle2, "*STATIC\n");
           fprintf (handle2, "%lf, %lf,,,\n", time2, time2);
-          fprintf (handle2, "**CLOAD, AMPLITUDE=FORCE%d\n", j);
-          fprintf (handle2, "**include, input=ccx.clo\n");
+          fprintf (handle2, "*CLOAD, AMPLITUDE=FORCE%d\n", j);
+          fprintf (handle2, "*include, input=ccx.clo\n");
           fprintf (handle2, "*DLOAD\n");
           fprintf (handle2, "Eall, CENTRIF, %f,  0., 0., 0.,  1., 0., 0\n", frc2*(atof(dat[2])/60.*2*PI)*(atof(dat[2])/60.*2*PI));
-          fprintf (handle2, "**DLOAD, AMPLITUDE=FORCE%d\n", j);
-          fprintf (handle2, "**include, input=ccx.dlo\n");
+          fprintf (handle2, "*DLOAD, AMPLITUDE=FORCE%d\n", j);
+          fprintf (handle2, "*include, input=ccx.dlo\n");
           fprintf (handle2, "*TEMPERATURE\n");
         }
   
